messagingapp/msgappfw/server/src/ccsconversation.cpp
changeset 25 84d9eb65b26f
parent 23 238255e8b033
child 37 518b245aa84c
child 47 5b14749788d7
--- a/messagingapp/msgappfw/server/src/ccsconversation.cpp	Fri Apr 16 14:56:15 2010 +0300
+++ b/messagingapp/msgappfw/server/src/ccsconversation.cpp	Mon May 03 12:29:07 2010 +0300
@@ -118,20 +118,15 @@
     }
 
 // ----------------------------------------------------------------------------
 // Get the Conversation Entry First name from Coversation Detail class
 // ----------------------------------------------------------------------------
 HBufC*
-CCsConversation::GetFirstName()const
+CCsConversation::GetDisplayName()const
     {
-    HBufC* fn = iContact->GetFirstName();
+    HBufC* fn = iContact->GetDisplayName();
     if ( fn && fn->Length() > 0 )
        return fn;
 
-    // If last name is present don't promote phone number as first name
-    HBufC* ln = iContact->GetLastName();
-    if ( ln && ln->Length() > 0 )
-       return NULL;
-
 	RPointerArray<TDesC> pnoList;
 	iContact->GetPhoneNumberList(pnoList);
 	if(pnoList.Count())
@@ -143,24 +138,6 @@
     }
 
 // ----------------------------------------------------------------------------
-// Get the Conversation Entry Last name from Coversation Detail class
-// ----------------------------------------------------------------------------
-HBufC*
-CCsConversation::GetLastName() const
-    {    
-    return iContact->GetLastName();
-    }
-
-// ----------------------------------------------------------------------------
-// Get the Conversation Entry Nick name from Coversation Detail class
-// ----------------------------------------------------------------------------
-HBufC*
-CCsConversation::GetNickName() const
-    {    
-    return iContact->GetNickName();
-    }
-
-// ----------------------------------------------------------------------------
 // CCsConversation::GetContactId
 // Get the Conversation Entry Contact Id from Coversation Detail class
 // ----------------------------------------------------------------------------
@@ -276,14 +253,10 @@
 void
 CCsConversation::AddContactDetailsL(
         TInt32  aContactId,
-        const TDesC& aFirstName,
-		const TDesC& aLastName,
-		const TDesC& aNickName)
+        const TDesC& aDisplayName)
     {
-    iContact->SetFirstNameL(aFirstName);
-    iContact->SetLastNameL(aLastName);
-    iContact->SetContactId (aContactId);
-    iContact->SetNickNameL(aNickName);
+    iContact->SetDisplayNameL(aDisplayName);
+    iContact->SetContactId (aContactId);    
     }
 
 // ----------------------------------------------------------------------------
@@ -118,20 +118,15 @@
 
 // ----------------------------------------------------------------------------
-// Get the Conversation Entry First name from Coversation Detail class
+// Get the Conversation Entry Display name from Coversation Detail class
 // ----------------------------------------------------------------------------
 HBufC*